@@ -29,7 +29,7 @@
 #' @param htot.m   Numeric vector of tree total height/s (in m). Length equal to dbh.cm vector or one.
 #'                 In this case same value will be replicated for all dbh.cm entries
 #' @param quantity (default = \code{vol}) Character vector specifying required quantity,
-#'                 one of \code{c("vol", "dw1" : "dw4")}. Use \code{qantities()} to retrieve
+#'                 one of \code{c("vol", "dw1" : "dw4")}. Use \code{Quantities()} to retrieve
 #'                 codes definitions. Length equal to dbh.cm vector or one.
 #'                 In this case same value will be replicated for all dbh.cm entries
 #'
@@ -42,7 +42,7 @@ INFCvpe <-
   function(EPPOcode, dbh.cm, htot.m, quantity = "vol") {
 
     # Verify that required quantities are recognised
-    if (!all(quantity %in% Quantities$quantity)) {cat("ERROR - Unrecognized esitimation quantity")}
+    if (!all(quantity %in% Quantities$quantity)) {cat("ERROR - Unrecognized estimation quantity")}
 
     assemble_D_0 <- function(x1, x2, n = 2) {
       # assemble the vector of the variable values, with appropriate length
@@ -84,6 +84,5 @@ INFCvpe <-
                                 , Var_ea = out$Var_ea
                                 , Var_ie = out$Var_ie
                                 , InDomain = out$ind)
-    
     return(out_col)
   }
